# Game Of Life

Simple way to play "game of life" using python

## Installation

Run the following to install:
``` python pip install game_of_life ```

## Usage

```python
from simple_game_of_life import GameOfLife
game = GameOfLife(50) 
game.start_animation()
```